<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>ئەپ ۋاكالەتچىسى</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ۋاكالەتچى تىپى</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP ئادرېسى</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>ئېغىز</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ئىشلەتكۈچى ئىسمى</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>ئىختىيارىي</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>پارول</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>تەڭشەلگەندىن كېيىن قوزغىتىش پروگراممىسىدىكى پروگرامما مەزمۇنى تىزىملىكىدىكى «ۋاكالەتچى ئىشلىتىڭ» نى تەكشۈرۈڭ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>ساقلاش</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>ئىناۋەتسىز IP ئادرېس</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>ئىناۋەتسىز ئېغىز</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>ئۈزۈش</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>ساقلاش</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>ئۈزۈش</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>بۇ سەپلىمىنى ئۆچۈرمەكچىمۇ؟</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>سىملىق ئۇلىنىش% 1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>تور تارقىتىش</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>سىمسىز ئۇلىنىش% 1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE ئۇلىنىشى% 1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>يېڭى VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN تىپى</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>چىقىرۋىلىش</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1 </translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>تور</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>ئەپ ۋاكالەتچىسى</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>شەخسىي سىمسىز تور</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>تور تەپسىلاتى</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>سىستېما ۋاكالەتچىلىكى</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>سىملىق تور</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>سىمسىز تور</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>ئۇچۇش ھالىتى</translation>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>سىملىق تور كارتىسى</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>تور تەڭشىكى قوشۇش</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>سىمسىز تور كارتىسى</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>يوشۇرۇن تورغا ئۇلىنىش</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE ئۇلىنىشى قۇرۇش</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN ھالىتى</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN قۇرۇش</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN ئەكىرىش</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ۋاكالەتچى تىپى</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>سەپلىمە ئادرېسى</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP ئادرېسى</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>ئېغىز</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>ئىشلەتكۈچى ئىسمى</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>پارول</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>تور تارقىتىش</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>تور تارقىتىش قۇرۇش</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>ئۇلىنىش ئېغىزى</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>دولقۇن بۆلىكى</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>تور قانىلى</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>شەخسىي DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>تور قەۋىتى</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>قوشۇمچە</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>تېزلىكى</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>ئۇچۇش ھالىتى</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>DNS ئادرېسى ئىناەتسىز</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>تور</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>باغلانمايدۇ</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>ئۈسكۈنە MAC ئادرېسى</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>كىلونلانغان MAC ئادرېسى</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU نى ئۆزى بەلگىلەش</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>ئورتاق</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>ئىسمى</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>ئورتاق</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>بۇ ئىسىم ئاللىبۇرۇن مەۋجۇت</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>ئىسمى</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>ئاپتوماتىك ئۇلانسۇن</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>تور تارقىتىش</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>تەڭشەك قوشۇش</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>تور تارقىتىش قۇرۇش</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP ئادرېسى</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>چوقۇم تولدۇرۇڭ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>تور قانىلى</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>IP ئادرېس قايتىلىنىپ قالدى</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>ئىناۋەتسىز IP ئادرېس</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>تارقاق تورنى نىقابلاش كودى ئىناۋەتسىز</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>بىرلا تور ئۆتكىلىگە رۇخسەت قىلىش</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>تور ئۆتكىلى ئادرېسى ئىناۋەتسىز</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>تور قەۋىتى</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>چوقۇم تولدۇرۇڭ</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>IP ئادرېس قايتىلىنىپ قالدى</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>ئىناۋەتسىز IP ئادرېس</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>بىرلا تور ئۆتكىلىگە رۇخسەت قىلىش</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>تور ئۆتكىلى ئادرېسى ئىناۋەتسىز</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>قوشۇمچە</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ئاپتوماتىك</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>قولدا</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>قوشۇلۇش</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP ئادرېسى</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>تور قانىلى</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>سېلىشتۇرما مەنبە ئىچىدىلا قوللىنىش</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>ئۇسۇل</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>تور قەۋىتى</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>قوشۇمچە</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>ئىناۋەتسىز IP ئادرېس</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>تارقاق تورنى نىقابلاش كودى ئىناۋەتسىز</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>تور ئۆتكىلى ئادرېسى ئىناۋەتسىز</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>تور</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ئادرېس توقۇنۇشۇپ قالدى</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>ئۇسۇل</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ئاپتوماتىك</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>قولدا</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>قوشۇلۇش</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>تور تەپسىلاتى</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>سىستېما ۋاكالەتچىلىكى</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>ئەپ ۋاكالەتچىسى</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>ئۇچۇش ھالىتى</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>تور تەپسىلاتى</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>تور</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ئادرېس توقۇنۇشۇپ قالدى</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>تاقاق</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>قولدا</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ئاپتوماتىك</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>تور باشقۇرغۇچى ئارقىلىق سەپلەش</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>شەخسىي سىمسىز تور</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ئىشلەتكۈچى ئىسمى</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>مۇلازىمەت</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>پارول</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP دەلىللەشنى رەت قىلىش</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP دەلىللەشنى رەت قىلىش</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP دەلىللەشنى رەت قىلىش</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP دەلىللەشنى رەت قىلىش</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 دەلىللەشنى رەت قىلىش</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>پىرېسلانغان BSD ئۇچۇرى يوق</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>پىرېسلانغان ئۇچۇر يوق</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>پىرېسلانغان TCP بېشى يوق</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>پىرېسلانغان كېلىشىم ئەزالىرى يوق</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>پىرېسلانغان ئادرېس كونتروللار يوق</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP ئۇچۇر بوغچىسى ئەۋەتىش</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE نى ئىشلىتىش</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE ھالىتى</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE ئۇلىنىشى قۇرۇش</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>سىستېما ۋاكالەتچىلىكى</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>ساقلاش</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ۋاكالەتچى تىپى</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>قولدا</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ئاپتوماتىك</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>ئىختىيارىي</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>ئېغىز</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP ۋاكالەتچىسى</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS ۋاكالەتچىسى</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP ۋاكالەتچىسى</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS ۋاكالەتچىسى</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>نۆۋەتتىكى ۋاكالەتچى سەپلىمىلىرىدە ئاۋۋالقى كومپيۇتېر ۋە دائىرە تەڭشەكلىرىگە ئېتىبارسىز قاراش</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>سەپلىمە ئادرېسى</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>بىخەتەرلىك</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>تونېلللانغان TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>قوغدالغان EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>مۇشۇ ئىشلەتكۈچىنىڭ پارولىنىلا ساقلش</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>بارلىق ئىشلەتكۈچىلەرنىڭ پارولىنى ساقلاش</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>دائىم جەزملەشتۈرسۇن</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>تاقاق</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>ئىمزاسىز</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>دەلىللەنگەن</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>ئىككى تەرەپ</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>ئاپتوماتىك</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>نەشر 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>نەشر 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP دەلىللەش</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>سالاھىيەت</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>پارول تاللاش</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>شەخسىي پارول</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA ئىمزاسى</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ئىشلەتكۈچى ئىمزاسى</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ئىمزاسىز ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>تەمىنلەۋاتىدۇ</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC ھۆججىتى</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>ئىچكى دەلىللەش</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP نەشرى</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>شەخسىي پارول</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>پارول</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>پارول ئىناۋەتسىز</translation>
    </message>
    <message>
        <source>None</source>
        <translation>قۇرۇق</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2شەخسى نۇسخىسى</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3شەخسى نۇسخىسى</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>بىخەتەرلىك</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>پارول</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>پارول</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>بىخەتەرلىك تەلەپ قىلىنىدۇ</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>پارول ئىناۋەتسىز</translation>
    </message>
    <message>
        <source>None</source>
        <translation>قۇرۇق</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2شەخسى نۇسخىسى</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 كارخانا</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3شەخسى نۇسخىسى</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>ئورتاقلانغان پارول</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>ئوچۇق سىستېما</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>بىخەتەرلىك</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>بىخەتەرلىك دەلىللەش تۈرى</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>پارول</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>پارول</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN ئالىي تەڭشەكلىرى</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>تور قانىلى ئېغىزىنى خاسلاشتۇرۇش</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>تور قانىلى ئېغىزى</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>كېڭىشىش قىممىتىنى خاسلاشتۇرۇش</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>كېڭىشىش قىممىتى</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZO ئارقىلىق پىرېسلاش</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCP ئارقىلىق ئۇلاش</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>TAP ئۈسكۈنىسى ئىشلىتىش</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>تونېل MTUنى خاسلاشتۇرۇش</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP پارچىسى چوڭلۇقىنى خاسلاشتۇرۇش</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP پارچىسى چوڭلۇقى</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>تونېل TCP MSS نى چەكلەش</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>يىراقتىكى ئاساسى ماشىنىنى ئىختىيارىيلاشتۇرۇش</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN ئالىي تەڭشەكلىرى</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (سۈكۈتتىكى)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>بىخەتەر (سۈكۈتتىكى)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>ئاجىز</translation>
    </message>
    <message>
        <source>None</source>
        <translation>قۇرۇق</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>ئەگەر ئىشلەتكىلى بولسا NAT-T (سۈكۈتتىكى)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T ھەمىشە</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>تاقاق</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH گۇرۇپپا 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH گۇرۇپپا 2 (سۈكۈتتىكى)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH گۇرۇپپا 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>مۇلازىمىتېر (سۈكۈتتىكى)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH گۇرۇپپا 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>دائىرە</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>تەمىنلىگۈچى</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>نەشرى</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>مەخپىيلەشتۈرۈش</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT ئېرگودىكى</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH گۇرۇپپىسى</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>مەخپىيەتلىكنى ئۆستۈرۈش</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>يەرلىكتىكى ئېغىز</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>ئۆلۈك زىيارەتنى بايقاشنى تاقاش</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN ئىنتېرنېت كېلىشىم بىخەتەرلىكى</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>ئىنتېرنېت كېلىشىم بىخەتەرلىكىنى قوزغىتىش</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>گۇرۇپپا ئىسمى</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>گۇرۇپپا نومۇرى</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pre-Shared ئاچقۇچى</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>پارول ئالماشتۇرۇش كېلىشىمى</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>بىخەتەر پېچەتلەش كېلىشىمى</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>تور ئۆتكىلى ئادرېسى ئىناۋەتسىز</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>تور قانىلى</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA ئىمزاسى</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>ۋاكالەتچىلىك</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Allow Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD قوليازما تىلى</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ئىشلەتكۈچى ئىمزاسى</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>شەخسىي پارول</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>پارولغا FSID نى ئىشلىتىش</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>تور ئۆتكىلى ئادرېسى ئىناۋەتسىز</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>گۇۋاھنامىلەر(TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>پارول</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>پارولغا مۇناسىۋەتلىك گۇۋاھنامىلەر (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>تىنىش پارول</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>ساقلاندى</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>دائىم جەزملەشتۈرسۇن</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>زۆرۈر ئەمەس</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>تور قانىلى</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>دەلىللەش تىپى</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA ئىمزاسى</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ئىشلەتكۈچى ئىمزاسى</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>شەخسىي پارول</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>پارول تاللاش</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>شەخسىي پارول</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ئىشلەتكۈچى ئىسمى</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>پارول يۆنىلىشىنى خاسلاشتۇرۇش</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>پارول يۆنىلىشى</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>يىراقتىكى IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>يەرلىكتىكى IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>بارلىق ئىشلەتكىلى بولىدىغان(سۈكۈتتىكى)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40 خانىلىك (بىخەتەرلىكى تۆۋەنرەك)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128 خانىلىك (ئىنتايىن بىخەتەر)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP دەلىللەشنى رەت قىلىش</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP دەلىللەشنى رەت قىلىش</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP دەلىللەشنى رەت قىلىش</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP دەلىللەشنى رەت قىلىش</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 دەلىللەشنى رەت قىلىش</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>پىرېسلانغان BSD ئۇچۇرى يوق</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>پىرېسلانغان ئۇچۇر يوق</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>پىرېسلانغان TCP بېشى يوق</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>پىرېسلانغان كېلىشىم ئەزالىرى يوق</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>پىرېسلانغان ئادرېس كونتروللار يوق</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP ئۇچۇر بوغچىسى ئەۋەتىش</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE نى ئىشلىتىش</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>بىخەتەرلىك</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE ھالىتى</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN ھالىتى</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN قۇرۇش</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN ئەكىرىش</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>ئەكىرىش مەغلۇپ بولدى</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>ھۆججەتنى كىرگۈزۈشتە خاتالىق بار</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>جەزىملەشتۈرۈش</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN ۋاكالەتچىسى</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>زۆرۈر ئەمەس</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ۋاكالەتچى تىپى</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>مۇلازىمىتېر IP ئادرېسى</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>ئېغىز</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>مەغلۇپ بولسا داۋاملىق قايتا سىناپ باقسۇن</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ئىشلەتكۈچى ئىسمى</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>پارول</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA ھۆججىتى</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>گۇۋاھنامە ئەسكەرتىشىنى ساقىت قىلىش</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>TLS ئاساسىي ئاپپاراتىنىڭ نامى ئارقىلىق كېڭەيتىش</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN بىخەتەرلىكى</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>سۈكۈتتىكى</translation>
    </message>
    <message>
        <source>None</source>
        <translation>قۇرۇق</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>مەخپىي بەلگە</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC دەلىللەش</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>تور ئۆتكىلى ئادرېسى ئىناۋەتسىز</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>ساقلاندى</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>دائىم جەزملەشتۈرسۇن</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>زۆرۈر ئەمەس</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>تور قانىلى</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ئىشلەتكۈچى ئىسمى</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>پارول تاللاش</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>پارول</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT دائىرىسى</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN ۋاكالەتچىسى</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>مۇلازىمىتېر IP ئادرېسى</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>ئېغىز</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ئىشلەتكۈچى ئىسمى</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>پارول</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>تور ئۆتكىلى ئادرېسى ئىناۋەتسىز</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>شەخسىي پارول</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH ۋەكىلى</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>ئەقلىي كارتا</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pre-Shared ئاچقۇچى</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>تور قانىلى</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA ئىمزاسى</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>دەلىللەش تىپى</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ئىشلەتكۈچى ئىمزاسى</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ئىشلەتكۈچى ئىسمى</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>پارول</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>ئىچكى IP ئادرېسى ئىلتىماس قىلىش</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>مەجبۇرىي UDP قىسقارتىش</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>IP پىرېسلاش</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>تەڭشەلگەن پاروللاش لايىھەسىنى قوزغىتىش</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS دەلىللەش</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>سۈكۈتتىكى</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>ئابۇنت</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>مۇلازىمىتېر</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>نىشان ماس كىلىش</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>يىراق مۇساپىلىك گۇۋاھنامە تۈرى</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>ئاچقۇچ ھۆججىتى</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>پارول يۆنىلىشىنى خاسلاشتۇرۇش</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>پارول يۆنىلىشى</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>تور ئۆتكىلى ئادرېسى ئىناۋەتسىز</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>ساقلاندى</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>دائىم جەزملەشتۈرسۇن</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>زۆرۈر ئەمەس</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>تور قانىلى</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ئىشلەتكۈچى ئىسمى</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>پارول تاللاش</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>پارول</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>گۇرۇپپا ئىسمى</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>گۇرۇپپا پارولى</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>ئارىلاشما دەلىللەش ئۇسۇلىنى قوللىنىش</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA ھۆججىتى</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>تور سىمىنى ئۇلاڭ!</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>سىملىق تور كارتىسى</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>تور تەڭشىكى قوشۇش</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>تەڭشەك تاللاش</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>سىمسىز تور كارتىسى</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>تور تارقىتىشنى تاقاش</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>سىمسىز تور ئىقتىدارىنى ئىشلەتمەكچى بولسىڭىز، ئاۋۋال تور تارقىتىشنى تاقاڭ</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>يوشۇرۇن تورغا ئۇلىنىش</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>سىمسىز تور</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>باغلانمايدۇ</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>زۆرۈر</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>ئۈسكۈنە MAC ئادرېسى</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU نى ئۆزى بەلگىلەش</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>تور تارقىتىش</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>كېلىشىم</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>بىخەتەرلىك تۈرى</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>قانال</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>دولقۇن بۆلىكى</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>ئۇلىنىش ئېغىزى</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>تور قەۋىتى</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>تور قانىلى</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>شەخسىي DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>قوشۇمچە</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>تېزلىكى</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>ئۈسكۈنە ئىشلىتىش چەكلەندى </translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>تورغا ئۇلاندى،ئەمما تورنى زىيارەت قىلالمىدى</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>ئۇلانمىدى</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>تور سىمى ئۇلانمىغان </translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>ئۇلىنىۋاتىدۇ</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>دەلىللەۋاتىدۇ</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP ئادرېسىغا ئېرىشىش </translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>ئۇلاندى</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>ئۈزۈلدى </translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ئادرېس توقۇنۇشۇپ قالدى</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>ئادرېسىغا ئېرىشىۋاتىدۇ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>سىملىق تور</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>سىملىق تور%1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>سىمسىز تور</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>سىمسىز تور%1</translation>
    </message>
</context>
</TS>